
** Notes for us to resolve before submitting final version.
** 1. Should we include rdiestax in specification 4 of table 5? With year*tax included, it isn't meaningful. In the 
**    submitted version, the omitted category was apparently tax*year2003
** 2. In column 4 of table 7, clustering was date*padd, while everywhere else it was just date.

******************************
*TABLES
******************************

*** Table 1 - Transitions in the point of tax collection  ***

use state_covariates, clear
tab diesPOT_change

*** Table 2 - Demographics and the point of tax collection  ***

use state_covariates, clear

*PANEL A*
foreach x in retail_diesel_price state_diesel_tax manuf_gsp mining_gsp GSP_shareFarming GSP_sharePetro_coal GSP_shareTrucking  {
xi: areg `x' diespaidD diespaidS, absorb(t) cluster(state)
}
*PANEL B*
foreach x in apop_adj gsp_capita unemployment urbanization bagrad hsgrad vmt_capita {
xi: areg `x' diespaidD diespaidS, absorb(t) cluster(state)
}
*PANEL C*
foreach x in budget_surplus senate_lcv house_lcv Democrat_Gov  demsfrac demhfrac {
xi: areg `x' diespaidD diespaidS, absorb(t) cluster(state)
}

*** Table 3 - Summary Statistics By Change in the Point of Diesel Tax Collection  ***

use state_covariates, clear

local varlist "retail_diesel_price state_diesel_tax gsp_capita unemployment manuf_gsp mining_gsp GSP_shareFarming GSP_sharePetro_coal GSP_shareTrucking apop_adj  urbanization fsize bagrad hsgrad vmt_capita budget_surplus senate_lcv house_lcv Democrat_Gov  demsfrac demhfrac"
*Summary statistics in columns (1) - (3)*
estpost tabstat `varlist' if year<2007, by(diesPOT_change_states) statistics(mean sd) columns(statistics)

*Difference in means t-test, clustered standard errors*
foreach x in `varlist' {
reg `x' diesPOT_change_states if year<2007, cluster(state)
}


*** Table 4 - Predictors of Tax Changes and Changes in the Point of Taxation  ***

use state_covariates, clear
drop if state_code=="HI" | state_code=="AK" | state_code=="DC"

collapse (mean) diespaid? retail_notax state_diesel_tax gsp_capita unemployment manuf_gsp mining_gsp GSP_shareFarming* GSP_sharePetro_coal* GSP_shareTrucking* apop_adj urbanization bagrad hsgrad vmt_capita budget_surplus senate_lcv house_lcv Democrat_Gov  demsfrac demhfrac if year<2007, by(state_code year statefips)
tsset statefips year

foreach x in retail_notax gsp_capita unemployment manuf_gsp mining_gsp apop_adj urbanization bagrad hsgrad vmt_capita budget_surplus senate_lcv house_lcv Democrat_Gov  demsfrac demhfrac{
gen d_`x' = d.`x'
}
foreach x in diespaidR diespaidD diespaidS state_diesel_tax {
gen delta_`x' = d.`x'
}

*first-differenced SIC data through 1997, 
*first-differenced NAICS data beginning in 1998
foreach x in GSP_shareFarming GSP_sharePetro_coal GSP_shareTrucking {
gen d_`x'_sic = d.`x'_sic
gen d_`x'_naics = d.`x'_naics
gen d_`x' = d_`x'_sic if year<1998
replace d_`x' = d_`x'_naics if year>1997
drop d_*_sic d_*_naics
}
 
areg delta_diespaidR d_* , absorb(year) cluster(year)
areg delta_diespaidD d_* , absorb(year) cluster(year)
areg delta_diespaidS d_* , absorb(year) cluster(year)
areg delta_state_diesel_tax d_* , absorb(year) cluster(year)


*** Table 5 - Point of Tax Collection and Incidence  ***
clear
use dataforpriceregs,clear

xi: cgmreg rnetoftax_retail rdiestax  rneighbtaxmin degreedays daysoilfrac unemploy i.statefips i.date1,robust  cluster(date1)
xi: cgmreg rnetoftax_retail rdiestax  taxsupp taxdist rneighbtaxmin degreedays daysoilfrac unemploy i.statefips i.date1,robust  cluster(date1)
xi: cgmreg rnetoftax_retail rdiestax  rdiestax_taxsupp rdiestax_taxdist taxsupp taxdist rneighbtaxmin  degreedays daysoilfrac unemploy i.statefips i.date1, robust  cluster(date1)
xi: cgmreg rnetoftax_retail           rdiestax_taxsupp rdiestax_taxdist taxsupp taxdist rneighbtaxmin  degreedays daysoilfrac unemploy i.statefips rdiestaxyear* i.date1,robust  cluster(date1)

*** Table 6 - Point of Tax Collection and Incidence ***
#delimit ;
xi: areg rnetoftax_retail rdiestax rdiestax_taxsupp taxsupp rneighbtaxmin 
	degreedays daysoilfrac unemploy i.date1 if statechangeddistsupp ,robust absorb(statefips) cluster(date1);
xi: areg rnetoftax_retail rdiestax rdiestax_reldatedistsupp reldatedistsupp rdiestax_taxsupp taxsupp rneighbtaxmin 
	degreedays daysoilfrac unemploy i.date1 if statechangeddistsupp ,robust absorb(statefips) cluster(date1);

	
xi: areg rnetoftax_retail rdiestax rdiestax_taxdist taxdist rneighbtaxmin 
	degreedays daysoilfrac unemploy i.date1 if statechangedretdist,robust absorb(statefips) cluster(date1);
xi: areg rnetoftax_retail rdiestax rdiestax_reldateretdist reldateretdist rdiestax_taxdist  taxdist rneighbtaxmin 
	degreedays daysoilfrac unemploy i.date1 if statechangedretdist ,robust absorb(statefips) cluster(date1);

#delimit cr
*** Table 7 - Point of Tax Collection and Wholesale Prices ***
xi: cgmreg rnetoftax_wholesale rdiestax  taxsupp taxdist rneighbtaxmin degreedays daysoilfrac unemploy i.statefips i.date1,robust  cluster(date1)
xi: cgmreg rnetoftax_wholesale rdiestax  rdiestax_taxsupp rdiestax_taxdist taxsupp taxdist rneighbtaxmin degreedays daysoilfrac unemploy i.statefips i.date1,robust  cluster(date1)

xi: cgmreg rnetoftax_retail rdiestax  rdiestax_taxsupp rdiestax_taxdist taxsupp taxdist rneighbtaxmin  degreedays daysoilfrac unemploy i.statefips i.date1, robust  cluster(date1)
xi: cgmreg rnetoftax_retail rdiestax  rdiestax_taxsupp rdiestax_taxdist taxsupp taxdist rnetoftax_wholesale lrnetoftax_wholesale rneighbtaxmin degreedays daysoilfrac unemploy i.statefips i.date1,robust  cluster(date1)


*** Table 8 - Pass-through and Wholesale Concentration  ***

*******************************************
*We cannot provide the market concentration data for replication due to a confidentiality agreement
*signed with the U.S. Energy Information Administration.
*The source for the wholesale volumes was the restricted EIA Form 782a data.
*The data was obtained by submitting a request to: 
*EIA data confidentiality office, Jacob Bournazian, Jacob.Bournazian@eia.gov.
*Hirschman-Herfindahl indices were calculated based on 
*wholesale volumes of low-sulfur diesel fuel reported to the EIA at the state*month level.
*The following code runs the regressions using dataforpriceregs, after merging
*with the market concentration data described above. 
*******************************************

/*
#delimit ;
use dataforpriceregs, clear;
egen meanHHI = mean(HHI_vol);
gen demean_HHI_vol = HHI_vol - meanHHI;

gen rdiestax_HHI = rdiestax*demean_HHI_vol;
gen demean_HHI_ret = demean_HHI_vol * diespaidby_R;
gen demean_HHI_dist = demean_HHI_vol * diespaidby_D;
gen demean_HHI_supp = demean_HHI_vol * diespaidby_S;
gen rdiestax_taxret_HHI = rdiestax_taxret*demean_HHI_vol;
gen rdiestax_taxdist_HHI = rdiestax_taxdist*demean_HHI_vol;
gen rdiestax_taxsupp_HHI = rdiestax_taxsupp*demean_HHI_vol;

label var demean_HHI_vol "Demeaned HHI";
label var demean_HHI_supp "Supp Remit * HHI";
label var demean_HHI_dist "Dist Remit * HHI";
label var demean_HHI_ret "Ret Remit * HHI";
label var rdiestax_HHI "Diesel Tax * HHI";
label var rdiestax_taxsupp_HHI "Supp Remit * Diesel Tax * HHI";
label var rdiestax_taxdist_HHI "Dist Remit * Diesel Tax * HHI";
label var rdiestax_taxret_HHI "Ret Remit * Diesel Tax * HHI";

*Column 1;
xi: reg rprice_reportedEIA rdiestax rdiestax_taxsupp rdiestax_taxdist 
diespaidby_S diespaidby_D rneighbtaxmin degreedays daysoilfrac unemploy 
i.yearmonth i.statefips, 
robust cluster(yearmonth);

*Column 2;
xi: reg rprice_reportedEIA rdiestax rdiestax_taxsupp rdiestax_taxdist 
diespaidby_S diespaidby_D rneighbtaxmin degreedays daysoilfrac unemploy 
i.yearmonth i.statefips if year>1993,
robust cluster(yearmonth);

*Column 3;
xi: reg rprice_reportedEIA rdiestax rdiestax_taxsupp rdiestax_taxdist 
diespaidby_S diespaidby_D rneighbtaxmin degreedays daysoilfrac unemploy 
rdiestax_HHI demean_HHI_vol 
i.yearmonth i.statefips if year>1993,
robust cluster(yearmonth);

*Column 4;
xi: reg rprice_reportedEIA rdiestax rdiestax_taxsupp rdiestax_taxdist 
diespaidby_S diespaidby_D rneighbtaxmin degreedays daysoilfrac unemploy 
demean_HHI_vol rdiestax_HHI 
demean_HHI_supp rdiestax_taxsupp_HHI 
demean_HHI_dist rdiestax_taxdist_HHI 
i.yearmonth i.statefips if year>1993,
robust cluster(yearmonth);
*/


*** Table 9 - Pass-through of Oil Price Shocks  ***

xi: cgmreg rnetoftax_retail rdiestax  rdiestax_taxsupp rdiestax_taxdist taxsupp taxdist rneighbtaxmin roilspot i.year i.month degreedays daysoilfrac unemploy i.statefips,robust  cluster(date1)
xi: cgmreg rnetoftax_retail rdiestax  rdiestax_taxsupp rdiestax_taxdist taxsupp taxdist rneighbtaxmin roilspot* i.year i.month degreedays daysoilfrac unemploy i.statefips,robust  cluster(date1)
xi: cgmreg rnetoftax_retail rdiestax  rdiestax_taxsupp rdiestax_taxdist taxsupp taxdist rneighbtaxmin degreedays daysoilfrac unemploy i.statefips i.date1,robust  cluster(date1)
xi: cgmreg rnetoftax_retail rdiestax  rdiestax_taxsupp rdiestax_taxdist taxsupp taxdist rneighbtaxmin roilspot_* degreedays daysoilfrac unemploy i.statefips i.date1,robust  cluster(date1)


*** Table 10 - other robustness checks  ***
xi: cgmreg rnetoftax_retail rdiestax  taxsupp taxdist rneighbtaxmin degreedays daysoilfrac unemploy i.statefips i.date1,robust  cluster(date1)
xi: cgmreg rnetoftax_retail rdiestax  rdiestax_taxsupp rdiestax_taxdist taxsupp taxdist rneighbtaxmin  degreedays daysoilfrac unemploy i.statefips i.date1, robust  cluster(date1)

xi: cgmreg rnetoftax_retail rdiestax  taxsupp taxdist rneighbtaxmin degreedays daysoilfrac unemploy i.statefips i.date1 if supp_plusminus2 & dist_plusminus2 ,robust  cluster(date1)
xi: cgmreg rnetoftax_retail rdiestax  rdiestax_taxsupp rdiestax_taxdist taxsupp taxdist rneighbtaxmin  degreedays daysoilfrac unemploy i.statefips i.date1 if supp_plusminus2 & dist_plusminus2, robust  cluster(date1)

xi: cgmreg rnetoftax_retail rdiestax  rdiestax_taxret taxret rneighbtaxmin  degreedays daysoilfrac unemploy i.statefips i.date1, robust  cluster(date1)
xi: ivreg rnetoftax_retail (rdiestax rdiestax_taxret=auto_r*)  taxretailer rneighbtaxmin degreedays daysoilfrac unemploy i.statefips i.date1,robust  cluster(date1)

*** Table 11   ***
use dataforcollectionregs,clear
areg lntaxedspecial taxsuppl taxdistr i.year, absorb(statefips) cluster(year)
areg lntaxedspecial taxsuppl taxdistr lnno2price lntaxrate_mp  i.year, absorb(statefips) cluster(year)
areg lntaxedspecial taxsuppl taxdistr lnno2price lntaxrate_mp lnneighbtaxmin unemp lngsp lndays lndays_oilfrac  i.year, absorb(statefips) cluster(year)
areg lntaxedspecial taxsuppl taxdistr lnno2price lntaxrate_mp taxsupp_lntaxrate_mp taxdist_lntaxrate_mp lnneighbtaxmin unemp lngsp lndays lndays_oilfrac i.year, absorb(statefips) cluster(year)
areg lntaxedspecial taxsuppl taxdistr lnno2price lntaxrate_mp taxsupp_lntaxrate_mp taxdist_lntaxrate_mp lnneighbtaxmin unemp lngsp lndays lndays_oilfrac i.year lntaxrate_year*, absorb(statefips) cluster(year)


******************************
*FIGURES
******************************

*** Figure 3  ***
use pointofcollection,clear
gen taxsupp = paidby=="S"
gen taxdist = paidby=="D"
gen taxret = paidby=="R"

keep year month taxsupp taxdist taxret
collapse (sum) taxsupp taxdist taxret , by(year month)
gen date_stata = ym(year,month)
sort date_stata
twoway line taxsupp taxdist taxret date_stata, legend(label(1 "Prime supplier") label(2 "Distributor") label(3 "Retailer")) title("Tax collection over time")

*** Figure 4 ***

use state_covariates, clear
gen dpb_map=1 if diespaidby=="R"
replace dpb_map=2 if diespaidby=="D"
replace dpb_map=3 if diespaidby=="S"
label define dpb_map 1 "Retailer" 2 "Distributor" 3 "Supplier", modify
label values dpb_map dpb_map

spmap dpb_map using US-Coordinates.dta if year==1990 & month==1, fcolor(gs15 gs10 gs6) clm(unique) id(id)
spmap dpb_map using US-Coordinates.dta if year==1997 & month==1, fcolor(gs15 gs10 gs6) clm(unique) id(id)
spmap dpb_map using US-Coordinates.dta if year==2004 & month==1, fcolor(gs15 gs10 gs6) clm(unique) id(id)

*** Figure 5 ***
use state_covariates, clear
collapse (mean) D_switch_year S_switch_year D_switch_state_tax S_switch_state_tax state_diesel_tax, by(state_code year statefips)

gen D_switch_year_relative = year - D_switch_year
gen S_switch_year_relative = year - S_switch_year
gen D_switch_state_tax_relative = state_diesel_tax - D_switch_state_tax 
gen S_switch_state_tax_relative = state_diesel_tax - S_switch_state_tax 
bys D_switch_year_relative: egen mean_tax_D_switch_relative = mean(D_switch_state_tax_relative)
bys S_switch_year_relative: egen mean_tax_S_switch_relative = mean(S_switch_state_tax_relative)

sort D_switch_year_relative
graph twoway line mean_tax_D_switch_relative D_switch_year_relative if abs(D_switch_year_relative)<8, legend(off) lp(-) xtitle("Year Relative to Switch to Distributor Remittance") ylabel(-5(2.5)5)  ytitle("Mean State Diesel Tax" "Relative to Switch Year (cpg)") 
sort S_switch_year_relative
graph twoway line mean_tax_S_switch_relative S_switch_year_relative if abs(S_switch_year_relative)<8, legend(off) lp(-) xtitle("Year Relative to Switch to Supplier Remittance") ylabel(-5(2.5)5)  ytitle("Mean State Diesel Tax" "Relative to Switch Year (cpg)") 

*** Figure 6  ***
** The coefficients from the following regressions are plotted in excel
use dataforcollectionregs,clear
xi: reg lntaxedspecial rettodist_minus2 rettodist_minus1 ret_to_dist rettodist_plus1 rettodist_plus2 rettosupp_minus2 rettosupp_minus1 ret_to_supp rettosupp_plus1 rettosupp_plus2 disttosupp_minus2 disttosupp_minus1 dist_to_supp disttosupp_plus1 disttosupp_plus2 i.year i.statefips if statefips~=2



